@@ -26,10 +26,14 @@
 //! Supported GNU/Linux and *BSD (incl OSX, but not guaranteed)
 //! 
 //! Files:
-//! - syslog_sync.rs - contains the thread-safe realization of the syslog (sync)
+//! - syslog_sync.rs - contains the thread-safe realization of the syslog (sync).
+//!     Thread safe. The Atomic and crossbeam backoff are used for sync.
 //! - syslog_async.rs - contains the async realization of the syslog (async)
+//!     Thread safe. Tokio mutex are used for sync.
 //! - syslog_sync_queue.rs - constains the sync realization, with asynchronious 
-//!     processing.
+//!     processing. The internal sych of crossbeam are used to push data to queue.
+//! - unsafe_cell.rs - a file contains a Cell which can be used to share the syslog
+//!     instance. See examples.
 //! - portable.rs - all system level code which is portable
 //! - common.rs - a common items
 //! - socket.rs - contains socket realization
@@ -42,6 +46,11 @@
 //! - feature = "use_sync_queue" for synchronious with async processing (use syslog_rs::sy_async_queue::{Syslog};)
 //!
 //! All features can be used simultaniously.
+//! # Usage
+//! 
+//! syslog-rs = {version = "0.1", default-features = false, features = ["use_sync"]}
+//! 
+//! By default, `use_sync` and `use_async` are enabled.
 
 #[macro_use] extern crate bitflags;
 #[cfg(any(feature = "use_sync", feature = "use_sync_queue"))]
@@ -68,6 +77,7 @@ pub mod socket;
 #[cfg(feature = "use_async")]
 pub mod async_socket;
 
+pub mod unsafe_cell;
 #[macro_use] pub mod common;
 #[macro_use] pub mod error;
 pub mod portable;
@@ -80,3 +90,4 @@ pub use syslog_async as sy_async;
 pub use syslog_sync_queue as sy_sync_queue;
 
 pub use common::*;
+pub use unsafe_cell::*;
