@@ -1,8 +1,23 @@
+/*-
+* syslog-rs - a syslog client translated from libc to rust
+* Copyright (C) 2021  Aleksandr Morozov
+* 
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU Lesser General Public
+* License as published by the Free Software Foundation; either
+* version 3 of the License, or (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* Lesser General Public License for more details.
+* 
+* You should have received a copy of the GNU Lesser General Public License
+* along with this program; if not, write to the Free Software Foundation,
+* Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
 
-#[cfg(feature = "use_async")]
-use tokio::net::UnixDatagram;
 
-#[cfg(not(feature = "use_async"))]
 use std::os::unix::net::UnixDatagram;
 
 use std::{
@@ -97,7 +112,6 @@ impl SyslogSocket
     }
 
     /// Writes to the socket. Will panic if instance is enum None.
-    #[cfg(not(feature = "use_async"))]
     pub(crate) fn send(&mut self, msg: &[u8]) -> std::io::Result<usize>
     {
         match *self
@@ -112,21 +126,6 @@ impl SyslogSocket
         } 
     }
 
-    #[cfg(feature = "use_async")]
-    pub(crate) async fn send(&mut self, msg: &[u8]) -> std::io::Result<usize>
-    {
-        match *self
-        {
-            Self::None => panic!("Assertion: wrong use of get_raw_fd()"),
-            Self::UnPriv(ref mut s) | 
-            Self::Priv(ref mut s) | 
-            Self::OldLog(ref mut s) =>
-            {
-                return s.send(msg).await;
-            }
-        } 
-    }
-
     /// Shutdowns the socket. Will panic if instance is enum None.
     pub(crate) fn shutdown(&mut self)
     {
