@@ -25,7 +25,16 @@ use tokio::sync::Mutex;
 
 use async_recursion::async_recursion;
 
-use chrono::{offset::Local, SecondsFormat};
+use chrono::offset::Local;
+
+#[cfg(any(
+    target_os = "freebsd",
+    target_os = "dragonfly",
+    target_os = "openbsd",
+    target_os = "netbsd",
+    target_os = "macos"
+))]
+use chrono::SecondsFormat;
 
 use super::async_socket::*;
 use super::portable;
@@ -702,6 +711,22 @@ impl Syslog
         // unlock 
         drop(lock);
     }
+
+    // --- NON STANDART API
+
+    /// This function can be used to update the facility name, for example
+    /// after fork().
+    /// 
+    /// # Arguments
+    /// 
+    /// * `ident` - a new identity (up to 48 UTF8 chars)
+    pub async fn change_identity<I: AsRef<str>>(&self, ident: I)
+    {
+        //lock
+        let mut lock = self.lock.lock().await;
+
+        lock.set_logtag(ident);
+    }
 }
 
 #[tokio::test(flavor = "multi_thread", worker_threads = 2)]
