@@ -25,7 +25,16 @@ use std::cell::RefCell;
 
 use crossbeam::utils::{Backoff, CachePadded};
 
-use chrono::{offset::Local, SecondsFormat};
+use chrono::offset::Local;
+
+#[cfg(any(
+    target_os = "freebsd",
+    target_os = "dragonfly",
+    target_os = "openbsd",
+    target_os = "netbsd",
+    target_os = "macos"
+))]
+use chrono::SecondsFormat;
 
 //use crate::{map_error, throw_error};
 
@@ -167,7 +176,7 @@ impl Syslog
         let timedate = Local::now().format("%h %e %T").to_string();
 
         // get appname
-        if self.option.exists_logtag() == true
+        if self.option.exists_logtag() == false
         {
             match portable::p_getprogname()
             {
@@ -358,7 +367,7 @@ impl Syslog
             Local::now().to_rfc3339_opts(SecondsFormat::Secs, false);
 
         // get appname
-        if self.option.exists_logtag() == true
+        if self.option.exists_logtag() == false
         {
             match portable::p_getprogname()
             {
@@ -555,7 +564,7 @@ impl Syslog
 
     /// Sets the logmask to filter out the syslog calls.
     /// 
-    /// See macroses [common::LOG_MASK] and [common::LOG_UPTO] to generate mask
+    /// See macroses [LOG_MASK] and [LOG_UPTO] to generate mask
     ///
     /// # Example
     ///
@@ -632,6 +641,19 @@ impl Syslog
         // unlock
         self.lock.store(false, Ordering::Release);
     }
+
+    // --- NON STANDART API
+
+    /// This function can be used to update the facility name, for example
+    /// after fork().
+    /// 
+    /// # Arguments
+    /// 
+    /// * `ident` - a new identity (up to 48 UTF8 chars)
+    pub fn change_identity<I: AsRef<str>>(&self, ident: I)
+    {
+        self.option.set_logtag(ident);
+    }
 }
 
 #[test]
