@@ -54,6 +54,10 @@ enum SyCmd
         logmask: i32, 
         loopback: Option<Sender<i32>>,
     },
+    ChangeIdentity
+    {
+        identity: String,
+    },
     Stop,
 }
 
@@ -84,6 +88,14 @@ impl SyCmd
         return ret;
     }
 
+    fn form_change_ident(identity: String) -> Self
+    {
+        return Self::ChangeIdentity
+            {
+                identity: identity
+            };
+    }
+
     fn form_stop() -> Self
     {
         return Self::Stop;
@@ -167,6 +179,10 @@ impl SyslogInternal
                                 let _ = lbk.send(pri);
                             }
                         },
+                        SyCmd::ChangeIdentity{identity} =>
+                        {
+                            self.option.set_logtag(identity);
+                        },
                         SyCmd::Stop =>
                         {
                             // ignore the rest
@@ -296,7 +312,7 @@ impl SyslogInternal
         let timedate = Local::now().format("%h %e %T").to_string();
 
         // get appname
-        if self.option.exists_logtag() == true
+        if self.option.exists_logtag() == false
         {
             match portable::p_getprogname()
             {
@@ -487,7 +503,7 @@ impl SyslogInternal
             Local::now().to_rfc3339_opts(SecondsFormat::Secs, false);
 
         // get appname
-        if self.option.exists_logtag() == true
+        if self.option.exists_logtag() == false
         {
             match portable::p_getprogname()
             {
@@ -821,6 +837,27 @@ impl Syslog
 
         return;
     }
+
+    // --- NON STANDART API
+
+    /// This function can be used to update the facility name, for example
+    /// after fork().
+    /// 
+    /// # Arguments
+    /// 
+    /// * `ident` - a new identity (up to 48 UTF8 chars)
+    pub fn change_identity<I: AsRef<str>>(&self, ident: I)
+    {
+        if self.run_control.upgrade().is_some() == true
+        {
+            let sy_cmd = 
+                SyCmd::form_change_ident(ident.as_ref().to_string());
+
+            self.tasks.push(sy_cmd);
+        }
+
+        return;
+    }
 }
 
 
